@@ -3,66 +3,58 @@ import logging
 import os
 import sys
 import traceback
-from pathlib import Path
 
 from vectorcode import __version__
 from vectorcode.cli_utils import (
     CliAction,
-    cli_arg_parser,
-    find_project_config_dir,
-    load_config_file,
-)
-from vectorcode.common import start_server, try_server
-from vectorcode.subcommands import (
-    check,
-    clean,
-    drop,
-    init,
-    ls,
-    query,
-    update,
-    vectorise,
+    find_project_root,
+    get_project_config,
+    parse_cli_args,
 )
 
 
 async def async_main():
-    cli_args = await cli_arg_parser()
+    cli_args = await parse_cli_args()
     if cli_args.no_stderr:
         sys.stderr = open(os.devnull, "w")
-    project_dir = await find_project_config_dir(cli_args.project_root or ".")
+    if cli_args.project_root is None:
+        cwd = os.getcwd()
+        cli_args.project_root = (
+            find_project_root(cwd, ".vectorcode")
+            or find_project_root(cwd, ".git")
+            or cwd
+        )
 
     try:
-        if project_dir is not None:
-            if cli_args.project_root is None:
-                cli_args.project_root = str(Path(project_dir).parent.resolve())
-
-            project_config_file = os.path.join(
-                cli_args.project_root, ".vectorcode", "config.json"
-            )
-            if os.path.isfile(project_config_file):
-                # has project-local config. use it
-                final_configs = await (
-                    await load_config_file(project_config_file)
-                ).merge_from(cli_args)
-            else:
-                # no project-local config. use global config.
-                final_configs = await (await load_config_file()).merge_from(cli_args)
-        else:
-            final_configs = await (await load_config_file()).merge_from(cli_args)
-            if final_configs.project_root is None:
-                final_configs.project_root = "."
+        final_configs = await (
+            await get_project_config(cli_args.project_root)
+        ).merge_from(cli_args)
     except IOError as e:
         traceback.print_exception(e, file=sys.stderr)
         return 1
 
     match cli_args.action:
         case CliAction.check:
+            from vectorcode.subcommands import check
+
             return await check(cli_args)
         case CliAction.init:
+            from vectorcode.subcommands import init
+
             return await init(cli_args)
         case CliAction.version:
             print(__version__)
             return 0
+        case CliAction.prompts:
+            from vectorcode.subcommands import prompts
+
+            return prompts(cli_args)
+        case CliAction.chunks:
+            from vectorcode.subcommands import chunks
+
+            return_val = await chunks(final_configs)
+
+    from vectorcode.common import start_server, try_server
 
     server_process = None
     if not await try_server(final_configs.host, final_configs.port):
@@ -81,16 +73,28 @@ async def async_main():
     try:
         match final_configs.action:
             case CliAction.query:
+                from vectorcode.subcommands import query
+
                 return_val = await query(final_configs)
             case CliAction.vectorise:
+                from vectorcode.subcommands import vectorise
+
                 return_val = await vectorise(final_configs)
             case CliAction.drop:
+                from vectorcode.subcommands import drop
+
                 return_val = await drop(final_configs)
             case CliAction.ls:
+                from vectorcode.subcommands import ls
+
                 return_val = await ls(final_configs)
             case CliAction.update:
+                from vectorcode.subcommands import update
+
                 return_val = await update(final_configs)
             case CliAction.clean:
+                from vectorcode.subcommands import clean
+
                 return_val = await clean(final_configs)
     except Exception as e:
         return_val = 1
@@ -102,9 +106,9 @@ async def async_main():
         return return_val
 
 
-def main():
+def main():  # pragma: nocover
     return asyncio.run(async_main())
 
 
-if __name__ == "__main__":
+if __name__ == "__main__":  # pragma: nocover
     sys.exit(main())
