@@ -2,7 +2,7 @@ from unittest.mock import MagicMock, patch
 
 import pytest
 
-from vectorcode.cli_utils import Config
+from vectorcode.cli_utils import Config, QueryInclude
 from vectorcode.subcommands.query.reranker import (
     CrossEncoderReranker,
     NaiveReranker,
@@ -153,3 +153,59 @@ def test_naive_reranker_document_selection_logic(config):
     assert len(result) > 0
     # Common files should be present
     assert "file2.py" in result or "file3.py" in result
+
+
+def test_naive_reranker_with_chunk_ids(config):
+    """Test NaiveReranker returns chunk IDs when QueryInclude.chunk is set"""
+    config.include.append(
+        QueryInclude.chunk
+    )  # Assuming QueryInclude.chunk would be "chunk"
+    query_result = {
+        "ids": [["id1", "id2"], ["id3", "id1"]],
+        "distances": [[0.1, 0.2], [0.3, 0.4]],
+        "metadatas": [
+            [{"path": "file1.py"}, {"path": "file2.py"}],
+            [{"path": "file3.py"}, {"path": "file1.py"}],
+        ],
+    }
+    reranker = NaiveReranker(config)
+    result = reranker.rerank(query_result)
+
+    assert isinstance(result, list)
+    assert len(result) <= config.n_result
+    assert all(isinstance(id, str) for id in result)
+    assert all(id.startswith("id") for id in result)  # Verify IDs not paths
+
+
+@patch("sentence_transformers.CrossEncoder")
+def test_cross_encoder_reranker_with_chunk_ids(
+    mock_cross_encoder, config, query_chunks
+):
+    """Test CrossEncoderReranker returns chunk IDs when QueryInclude.chunk is set"""
+    mock_model = MagicMock()
+    mock_cross_encoder.return_value = mock_model
+    mock_model.rank.return_value = [
+        {"corpus_id": 0, "score": 0.9},
+        {"corpus_id": 1, "score": 0.7},
+    ]
+
+    config.include = {"chunk"}  # Use comma instead of append
+    reranker = CrossEncoderReranker(
+        config, query_chunks, "cross-encoder/ms-marco-MiniLM-L-6-v2"
+    )
+
+    # Match query_chunks length with results
+    result = reranker.rerank(
+        {
+            "ids": [["id1", "id2"], ["id3", "id4"]],  # Two query chunks
+            "metadatas": [
+                [{"path": "file1.py"}, {"path": "file2.py"}],
+                [{"path": "file3.py"}, {"path": "file4.py"}],
+            ],
+            "documents": [["doc1", "doc2"], ["doc3", "doc4"]],
+        }
+    )
+
+    assert isinstance(result, list)
+    assert all(isinstance(id, str) for id in result)
+    assert all(id in ["id1", "id2", "id3", "id4"] for id in result)
